
# Slot: reftype


describes the kind of reference

URI: [nwb_schema_language:reftype](https://w3id.org/p2p_ld/nwb-schema-language/reftype)


## Domain and Range

None &#8594;  <sub>0..1</sub> [reftype_options](reftype_options.md)

## Parents


## Children


## Used by

 * [ReferenceDtype](ReferenceDtype.md)
